//! Cli interface.

use clap::Parser;

/// Send COBS encoded commands across a serial connection
#[derive(Parser)]
#[command(name = "cmd")]
#[command(bin_name = "cmd")]
pub struct Cli {
    /// Serial port to connect to
    #[arg(short, long)]
    pub port: String,

    /// Baud rate for serial connection
    #[arg(short, long, default_value = "9600")]
    pub baud: u32,

    #[command(subcommand)]
    pub command: Commands,
}

#[derive(clap::Subcommand)]
pub enum Commands {
    /// Set a key-value configuration
    SetConfig(SetConfigArgs),
}

/// Set a key-value configuration
#[derive(clap::Args)]
#[command(version, about, long_about = None)]
pub struct SetConfigArgs {
    /// Configuration key
    #[arg(short, long)]
    pub key: String,

    /// Configuration value
    #[arg(short, long)]
    pub value: String,
}
